@@ -21,6 +21,8 @@ pub use serde_json::json;
 pub use structopt::StructOpt;
 pub use reqwest;
 
+pub type MgmtChannel = ClientMgmtChannel;
+
 pub type JsV = serde_json::Value;
 pub type MC = MgmtCommand;
 
@@ -580,6 +582,7 @@ pub fn prepare_tmpdir<'x>(opts: &'x Opts, mut current_exe: &'x str) -> DirSubst
 
   env::set_var("HOME", &abstmp);
   env::set_var("TMPDIR", &abstmp);
+  env::set_var("OTTER_APITEST_START_DIR", &start_dir);
   for v in "http_proxy https_proxy XAUTHORITY CDPATH \
             SSH_AGENT_PID SSH_AUTH_SOCK WINDOWID WWW_HOME".split(' ')
   {
@@ -621,6 +624,9 @@ shapelibs = [ "@src@/library/*.toml" ]
 libexec_dir = "@target@/debug"
 usvg_bin = "@target@/release/usvg"
 
+authorized_keys = "@abstmp@/authorized_keys"
+ssh_proxy_command = "@target@/debug/otter-ssh-proxy --config @abstmp@/server-config.toml"
+
 debug_js_inject_file = "@src@/templates/log-save.js"
 check_bundled_sources = false # For testing only! see LICENCE!
 
